@@ -1,29 +1,30 @@
 package Crypt::XkcdPassword;
 
 use 5.010001;
-use Object::AUTHORITY;
 use utf8;
 
 BEGIN {
 	$Crypt::XkcdPassword::AUTHORITY = 'cpan:TOBYINK';
-	$Crypt::XkcdPassword::VERSION   = '0.003';
+	$Crypt::XkcdPassword::VERSION   = '0.004';
 }
 
 use Carp qw/carp croak/;
 use Class::Load qw/try_load_class/;
-use Moo;
+
+use Any::Moose;
+use Object::AUTHORITY;
 
 has rng => (
 	is      => 'rw',
-	isa     => sub { ref $_[0] eq 'CODE' },
+	isa     => 'CodeRef',
 	default => sub { sub { int(rand($_[0])) } },
-	);
+);
 
 has words => (
 	is      => 'rw',
-	isa     => sub { !ref $_[0] },
-	default => sub { 'EN' },
-	);
+	isa     => 'Str',
+	default => 'EN',
+);
 
 *chars = *provider = sub {};
 
@@ -97,8 +98,7 @@ many passwords as you like.
 
 =head2 Attributes
 
-This module doesn't use Moose, but uses its "mini-me", L<Mo>. Like Moose,
-Mo provides the concept of attributes, which have a getter/setter method.
+This is a Moose (well, L<Any::Moose>) based class.
 
 =over
 
@@ -112,6 +112,11 @@ C<< Crypt::XkcdPassword::Words::EN >>.
 C<< Crypt::XkcdPassword::Words::EN >> is a list of 10,000 common English
 words.
 
+C<< Crypt::XkcdPassword::Words::EN::Roget >> is a list of about 8500
+words. The words are less questionable, but as there are fewer of them,
+pass phrases will be chosen from a smaller pool, thus slightly more
+guessable.
+
 Also supplied is "IT", a list of 20,000 common Italian words.
 
 =item * C<< rng >>
